@@ -151,7 +151,6 @@ postProcessTo <- function(from, to,
                           cropTo = NULL, projectTo = NULL, maskTo = NULL, writeTo = NULL,
                           overwrite = TRUE, verbose = getOption("reproducible.verbose"),
                           ...) {
-
   startTime <- Sys.time()
   remapOldArgs(...) # converts studyArea, rasterToMatch, filename2, useSAcrs, targetCRS
 
@@ -194,22 +193,25 @@ postProcessTo <- function(from, to,
   if (isRaster) {
     fromCRS <- terra::crs(from)
     from <- terra::rast(from)
-    if (!nzchar(terra::crs(from)))
-      terra::crs(from) <- fromCRS#$input
+    if (!nzchar(terra::crs(from))) {
+      terra::crs(from) <- fromCRS
+    } # $input
   } else if (isSpatial) {
     osFrom <- object.size(from)
     lg <- osFrom > 5e8
     if (lg) {
       st <- Sys.time()
       messagePrepInputs("  `from` is large, converting to terra object will take some time ...",
-                        verbose = verbose)
+        verbose = verbose
+      )
     }
     from <- suppressWarningsSpecific(terra::vect(from), shldBeChar)
     if (lg) {
       messagePrepInputs("  done in ", format(difftime(Sys.time(), st),
-                                             units = "secs", digits = 3),
-                        verbose = verbose)
-
+        units = "secs", digits = 3
+      ),
+      verbose = verbose
+      )
     }
   }
 
@@ -222,24 +224,30 @@ postProcessTo <- function(from, to,
   from <- cropTo(from, cropTo, needBuffer = FALSE, ..., overwrite = overwrite) # need to recrop to trim excess pixels in new projection
 
   # Put this message near the end so doesn't get lost
-  if (is.naSpatial(cropTo) && isVector(maskTo))  {
+  if (is.naSpatial(cropTo) && isVector(maskTo)) {
     messagePrepInputs("    ** cropTo is NA, but maskTo is a Vector dataset; ",
-                      verbose = verbose)
+      verbose = verbose
+    )
     messagePrepInputs("      this has the effect of cropping anyway",
-                      verbose = verbose)
+      verbose = verbose
+    )
   }
 
   # from <- terra::setMinMax(from)
 
   # WRITE STEP
-  from <- writeTo(from, writeTo, overwrite, isStack, isBrick, isRaster, isSpatRaster,
-                  ...)
+  from <- writeTo(
+    from, writeTo, overwrite, isStack, isBrick, isRaster, isSpatRaster,
+    ...
+  )
 
   # REVERT TO ORIGINAL INPUT CLASS
   from <- revertClass(from, isStack, isBrick, isRasterLayer, isSF, isSpatial)
   messagePrepInputs("  postProcessTo done in ", format(difftime(Sys.time(), startTime),
-                                                          units = "secs", digits = 3),
-                    verbose = verbose)
+    units = "secs", digits = 3
+  ),
+  verbose = verbose
+  )
   from
 }
 
@@ -252,13 +260,13 @@ isSpatVector <- function(x) is(x, "SpatVector")
 isSpat <- function(x) is(x, "SpatRaster") || isSpatVector(x)
 isSpat2 <- function(origClass) any(origClass %in% c("SpatVector", "SpatRaster"))
 isGridded <- function(x) is(x, "SpatRaster") || is(x, "Raster")
-isVector <-  function(x) isSpatVector(x) || is(x, "Spatial") || isSF(x)
+isVector <- function(x) isSpatVector(x) || is(x, "Spatial") || isSF(x)
 isSpatialAny <- function(x) isGridded(x) || isVector(x)
 isSF <- function(x) is(x, "sf") || is(x, "sfc")
 isRaster <- function(x) is(x, "Raster")
 isCRSANY <- function(x) isCRSSF(x) || isCRScharacter(x) || isCRSTerra(x)
 isCRSSF <- function(x) is(x, "crs")
-isCRScharacter <- function(x) is.character(x) && ( grepl("DATUM", x)  || grepl("+proj", x))
+isCRScharacter <- function(x) is.character(x) && (grepl("DATUM", x) || grepl("+proj", x))
 isCRSTerra <- function(x) is(x, "CRS")
 
 #' Fix common errors in GIS layers, using `terra`
@@ -280,17 +288,22 @@ fixErrorsIn <- function(x, error = NULL, verbose = getOption("reproducible.verbo
     if (!is.null(error)) {
       messageDeclareError(error, fromFnName, verbose)
       os <- objSize(x)
-      if (os > 1e9)
+      if (os > 1e9) {
         messagePrepInputs("... this may take a long time because the object is large (",
-                        format(os), ")", verbose = verbose)
+          format(os), ")",
+          verbose = verbose
+        )
+      }
     }
     if (isSF(x)) {
       .requireNamespace("sf", stopOnFALSE = TRUE)
       xValids <- sf::st_is_valid(x)
       if (any(!xValids)) {
-        if (os > 1e9)
+        if (os > 1e9) {
           messagePrepInputs("... found invalid components ... running sf::st_make_valid",
-                          verbose = verbose)
+            verbose = verbose
+          )
+        }
 
         x <- sf::st_make_valid(x)
       }
@@ -299,7 +312,6 @@ fixErrorsIn <- function(x, error = NULL, verbose = getOption("reproducible.verbo
         origClass <- class(x)
         isSp <- isSpatial(x)
         x <- terra::vect(x)
-
       }
       if (os > 1e9 && isTRUE(getOption("reproducible.useCache"))) {
         messagePrepInputs("... Caching the fixErrorTerra call on this large object", verbose = verbose)
@@ -307,9 +319,9 @@ fixErrorsIn <- function(x, error = NULL, verbose = getOption("reproducible.verbo
       } else {
         x <- makeVal(x)
       }
-      if (exists("origClass", inherits = FALSE))
+      if (exists("origClass", inherits = FALSE)) {
         x <- revertClass(x, isSpatial = isSp, origFromClass = origClass)
-
+      }
     }
   }
   x
@@ -318,8 +330,9 @@ fixErrorsIn <- function(x, error = NULL, verbose = getOption("reproducible.verbo
 makeVal <- function(x) {
   xValids <- terra::is.valid(x)
 
-  if (any(!xValids))
+  if (any(!xValids)) {
     x <- terra::makeValid(x)
+  }
 
   x
   #
@@ -349,7 +362,6 @@ makeVal <- function(x) {
 maskTo <- function(from, maskTo, # touches = FALSE,
                    overwrite = FALSE,
                    verbose = getOption("reproducible.verbose"), ...) {
-
   remapOldArgs(...) # converts studyArea, rasterToMatch, filename2, useSAcrs, targetCRS
 
   if (!is.null(maskTo) && !extntNA(from) && !extntNA(maskTo)) {
@@ -359,14 +371,17 @@ maskTo <- function(from, maskTo, # touches = FALSE,
       if (isRaster(maskTo)) {
         maskTo <- terra::rast(maskTo)
       }
-      if (isGridded(maskTo) && isVector(from))
+      if (isGridded(maskTo) && isVector(from)) {
         omit <- TRUE
-      if (!isSpatialAny(maskTo))
+      }
+      if (!isSpatialAny(maskTo)) {
         if (is.na(maskTo) || isCRSANY(maskTo)) omit <- TRUE
+      }
 
       if (!omit) {
-        if (isSF(from) || isSF(projectTo))
+        if (isSF(from) || isSF(projectTo)) {
           .requireNamespace("sf", stopOnFALSE = TRUE)
+        }
         if (isSpatial(from)) {
           from <- sf::st_as_sf(from)
         }
@@ -406,7 +421,6 @@ maskTo <- function(from, maskTo, # touches = FALSE,
               }
               maskTo <- terra::project(maskTo, from)
             }
-
           }
         }
         messagePrepInputs("    masking...", appendLF = FALSE, verbose = verbose)
@@ -419,48 +433,54 @@ maskTo <- function(from, maskTo, # touches = FALSE,
         attempt <- 1
         triedFrom <- NA
         while (attempt <= 2) {
-          fromInt <- try({
-            if (isVector(maskTo)) {
-              if (length(maskTo) > 1) {
-                if (isSF(maskTo)) {
-                  maskTo <- sf::st_union(maskTo)
+          fromInt <- try(
+            {
+              if (isVector(maskTo)) {
+                if (length(maskTo) > 1) {
+                  if (isSF(maskTo)) {
+                    maskTo <- sf::st_union(maskTo)
+                  } else {
+                    maskTo <- terra::aggregate(maskTo)
+                  }
+                }
+              }
+
+              if (isVector(from)) {
+                if (isSF(from)) {
+                  sf::st_intersection(from, maskTo)
                 } else {
-                  maskTo <- terra::aggregate(maskTo)
+                  if (getRversion() == "4.3.0") { # TODO: this is a work around for R crashing; shouldn't b/c this is in a `try`
+                    maskTo <- fixErrorsIn(maskTo)
+                  }
+                  terra::intersect(from, maskTo)
                 }
-              }
-            }
-
-            if (isVector(from)) {
-              if (isSF(from)) {
-                sf::st_intersection(from, maskTo)
               } else {
-                if (getRversion() == "4.3.0") { # TODO: this is a work around for R crashing; shouldn't b/c this is in a `try`
-                  maskTo <- fixErrorsIn(maskTo)
-                }
-                terra::intersect(from, maskTo)
-              }
-            } else {
-              if (isGridded(maskTo)) {
-                if (terra::ext(from) > terra::ext(maskTo))
-                  from <- terra::crop(from, maskTo)
-                if (terra::ext(maskTo) > terra::ext(from))
-                  maskTo <- terra::crop(maskTo, from)
-                terra::mask(from, maskTo, overwrite = overwrite)
-              } else {
-                if (isSF(maskTo) || isSpatial(maskTo)) {
-                  maskTo <- terra::vect(maskTo) # alternative is stars, and that is not Suggests
-                }
+                if (isGridded(maskTo)) {
+                  if (terra::ext(from) > terra::ext(maskTo)) {
+                    from <- terra::crop(from, maskTo)
+                  }
+                  if (terra::ext(maskTo) > terra::ext(from)) {
+                    maskTo <- terra::crop(maskTo, from)
+                  }
+                  terra::mask(from, maskTo, overwrite = overwrite)
+                } else {
+                  if (isSF(maskTo) || isSpatial(maskTo)) {
+                    maskTo <- terra::vect(maskTo) # alternative is stars, and that is not Suggests
+                  }
 
-                dotArgs <- intersect(...names(), c(writeRasterArgs, maskArgs))
-                if (length(dotArgs))
-                  dotArgs <- list(...)[dotArgs]
-                ll <- append(list(from, maskTo, overwrite = overwrite), dotArgs)
-                do.call(terra::mask, ll)
+                  dotArgs <- intersect(...names(), c(writeRasterArgs, maskArgs))
+                  if (length(dotArgs)) {
+                    dotArgs <- list(...)[dotArgs]
+                  }
+                  ll <- append(list(from, maskTo, overwrite = overwrite), dotArgs)
+                  do.call(terra::mask, ll)
 
-                # terra::mask(from, maskTo, touches = touches, overwrite = overwrite)
+                  # terra::mask(from, maskTo, touches = touches, overwrite = overwrite)
+                }
               }
-            }
-          }, silent = TRUE)
+            },
+            silent = TRUE
+          )
           if (is(fromInt, "try-error")) {
             if (attempt == 1) {
               whichFailed <- grepl("geom 0|Loop 0", fromInt)
@@ -475,8 +495,9 @@ maskTo <- function(from, maskTo, # touches = FALSE,
               stop(fromInt)
             }
           } else {
-            if (attempt > 1)
-              messagePrepInputs("...fixed!", verbose = verbose, verboseLevel = 1 , appendLF = FALSE)
+            if (attempt > 1) {
+              messagePrepInputs("...fixed!", verbose = verbose, verboseLevel = 1, appendLF = FALSE)
+            }
             break
           }
           attempt <- attempt + 1
@@ -484,8 +505,9 @@ maskTo <- function(from, maskTo, # touches = FALSE,
 
         from <- fromInt
         messagePrepInputs("...done in ",
-                          format(difftime(Sys.time(), st), units = "secs", digits = 3),
-                          verbose = verbose)
+          format(difftime(Sys.time(), st), units = "secs", digits = 3),
+          verbose = verbose
+        )
         from <- revertClass(from, origFromClass = origFromClass)
       }
     }
@@ -497,7 +519,6 @@ maskTo <- function(from, maskTo, # touches = FALSE,
 #' @rdname postProcessTo
 projectTo <- function(from, projectTo, overwrite = FALSE,
                       verbose = getOption("reproducible.verbose"), ...) {
-
   remapOldArgs(...) # converts studyArea, rasterToMatch, filename2, useSAcrs, targetCRS
 
   hasMethod <- which(...names() %in% "method")
@@ -532,88 +553,103 @@ projectTo <- function(from, projectTo, overwrite = FALSE,
       #   messagePrepInputs("    projection of from is same as projectTo, not projecting",
       #                     verbose = verbose)
       # } else {
-        if (isSF(from) || isSF(projectTo))
-          .requireNamespace("sf", stopOnFALSE = TRUE)
-        messagePrepInputs("    projecting...", appendLF = FALSE,
-                          verbose = verbose)
-        st <- Sys.time()
-        if (isProjectToVecOrCRS && ( isSF(projectTo) || isSpatial(projectTo) ) ) {
-          projectToTmp <- sf::st_as_sfc(sf::st_bbox(from))
-          if (isVector(projectTo))
-            projectTo <- sf::st_crs(projectTo)
-          projectToTmp <- sf::st_transform(projectToTmp, projectTo)
-          projectTo <- terra::vect(projectToTmp)
-        }
-
+      if (isSF(from) || isSF(projectTo)) {
+        .requireNamespace("sf", stopOnFALSE = TRUE)
+      }
+      messagePrepInputs("    projecting...",
+        appendLF = FALSE,
+        verbose = verbose
+      )
+      st <- Sys.time()
+      if (isProjectToVecOrCRS && (isSF(projectTo) || isSpatial(projectTo))) {
+        projectToTmp <- sf::st_as_sfc(sf::st_bbox(from))
         if (isVector(projectTo)) {
-          if (isGridded(from)) {
-            if (!isSpat(projectTo))
-              projectTo <- terra::vect(projectTo)
+          projectTo <- sf::st_crs(projectTo)
+        }
+        projectToTmp <- sf::st_transform(projectToTmp, projectTo)
+        projectTo <- terra::vect(projectToTmp)
+      }
 
-            messagePrepInputs("", verbose = verbose)
-            messagePrepInputs("         projectTo is a Vector dataset, which does not define all metadata required. ",
-                              verbose = verbose)
-            if (!terra::is.lonlat(from)) {
+      if (isVector(projectTo)) {
+        if (isGridded(from)) {
+          if (!isSpat(projectTo)) {
+            projectTo <- terra::vect(projectTo)
+          }
+
+          messagePrepInputs("", verbose = verbose)
+          messagePrepInputs("         projectTo is a Vector dataset, which does not define all metadata required. ",
+            verbose = verbose
+          )
+          if (!terra::is.lonlat(from)) {
             # if (sf::st_crs("epsg:4326") != sf::st_crs(from)) {
-              newRes <- terra::res(from)
-              messagePrepInputs("         Using resolution of ",paste(newRes, collapse = "x"),"m; ",
-                                verbose = verbose)
-              projectTo <- terra::rast(projectTo, resolution = newRes)
-            } else {
-              projectTo <- terra::crs(projectTo)
-            }
-
-            messagePrepInputs("         in the projection of `projectTo`, using the origin and extent",
-                              verbose = verbose)
-            messagePrepInputs("         from `ext(from)` (in the projection from `projectTo`).",
-                              verbose = verbose)
-            messagePrepInputs("         If this is not correct, create a template gridded object and pass that to projectTo...",
-                              verbose = verbose)
-            messagePrepInputs("         ", appendLF = FALSE,
-                              verbose = verbose)
-
+            newRes <- terra::res(from)
+            messagePrepInputs("         Using resolution of ", paste(newRes, collapse = "x"), "m; ",
+              verbose = verbose
+            )
+            projectTo <- terra::rast(projectTo, resolution = newRes)
           } else {
             projectTo <- terra::crs(projectTo)
-            # projectTo <- sf::st_crs(projectTo)$wkt
-          }
-        }
-
-        # Since we only use the crs when projectTo is a Vector, no need to "fixErrorsIn"
-        from <- if (isVector(from)) {
-          isSpatial <- isSpatial(from)
-          if (isSpatial)
-            from <- suppressWarningsSpecific(terra::vect(from), shldBeChar)
-          isSF <- isSF(from)
-          if (isSF) {
-            if (isGridded(projectTo)) {
-              projectTo <- sf::st_crs(projectTo)
-            }
-            from <- sf::st_transform(from, projectTo)
-          } else {
-            from <- terra::project(from, projectTo)
           }
 
-          if (isSpatial) from <- as(from, "Spatial")
-          from
+          messagePrepInputs("         in the projection of `projectTo`, using the origin and extent",
+            verbose = verbose
+          )
+          messagePrepInputs("         from `ext(from)` (in the projection from `projectTo`).",
+            verbose = verbose
+          )
+          messagePrepInputs("         If this is not correct, create a template gridded object and pass that to projectTo...",
+            verbose = verbose
+          )
+          messagePrepInputs("         ",
+            appendLF = FALSE,
+            verbose = verbose
+          )
         } else {
-          dotArgs <- intersect(...names(), c(writeRasterArgs, projectArgs))
-          if (length(dotArgs))
-            dotArgs <- list(...)[dotArgs]
-          sameGeom <- if (isSpat(from) && isSpat(projectTo) ||
-                          (isRaster(from) || isRaster(projectTo)))
-            terra::compareGeom(from, projectTo, stopOnError = FALSE)
-          else
-            FALSE
-          if (!isTRUE(sameGeom)) {
-            ll <- append(list(from, projectTo, overwrite = overwrite), dotArgs)
-            do.call(terra::project, ll)
-          } else {
-            from
-          }
+          projectTo <- terra::crs(projectTo)
+          # projectTo <- sf::st_crs(projectTo)$wkt
         }
-        messagePrepInputs("done in ", format(difftime(Sys.time(), st), units = "secs", digits = 3),
-                          verbose = verbose)
       }
+
+      # Since we only use the crs when projectTo is a Vector, no need to "fixErrorsIn"
+      from <- if (isVector(from)) {
+        isSpatial <- isSpatial(from)
+        if (isSpatial) {
+          from <- suppressWarningsSpecific(terra::vect(from), shldBeChar)
+        }
+        isSF <- isSF(from)
+        if (isSF) {
+          if (isGridded(projectTo)) {
+            projectTo <- sf::st_crs(projectTo)
+          }
+          from <- sf::st_transform(from, projectTo)
+        } else {
+          from <- terra::project(from, projectTo)
+        }
+
+        if (isSpatial) from <- as(from, "Spatial")
+        from
+      } else {
+        dotArgs <- intersect(...names(), c(writeRasterArgs, projectArgs))
+        if (length(dotArgs)) {
+          dotArgs <- list(...)[dotArgs]
+        }
+        sameGeom <- if (isSpat(from) && isSpat(projectTo) ||
+          (isRaster(from) || isRaster(projectTo))) {
+          terra::compareGeom(from, projectTo, stopOnError = FALSE)
+        } else {
+          FALSE
+        }
+        if (!isTRUE(sameGeom)) {
+          ll <- append(list(from, projectTo, overwrite = overwrite), dotArgs)
+          do.call(terra::project, ll)
+        } else {
+          from
+        }
+      }
+      messagePrepInputs("done in ", format(difftime(Sys.time(), st), units = "secs", digits = 3),
+        verbose = verbose
+      )
+    }
     # }
     from <- revertClass(from, origFromClass = origFromClass)
   }
@@ -628,12 +664,12 @@ projectTo <- function(from, projectTo, overwrite = FALSE,
 #' @rdname postProcessTo
 cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
                    verbose = getOption("reproducible.verbose"), ...) {
-
   remapOldArgs(...) # converts studyArea, rasterToMatch, filename2, useSAcrs, targetCRS
 
   if (!is.null(cropTo) && !extntNA(from) && !extntNA(cropTo)) {
-    if (isSF(from) || isSF(cropTo))
+    if (isSF(from) || isSF(cropTo)) {
       .requireNamespace("sf", stopOnFALSE = TRUE)
+    }
     omit <- FALSE
     origFromClass <- is(from)
 
@@ -645,17 +681,22 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
       }
     }
 
-    if (!isSpatialAny(cropTo))
+    if (!isSpatialAny(cropTo)) {
       if (is.na(cropTo) || isCRSANY(cropTo)) omit <- TRUE
+    }
 
     if (!omit) {
-      if (isSpatial(cropTo))
+      if (isSpatial(cropTo)) {
         cropTo <- terra::vect(cropTo)
-      if (isSpatial(from))
+      }
+      if (isSpatial(from)) {
         from <- terra::vect(from)
+      }
 
-      messagePrepInputs("    cropping..." , appendLF = FALSE,
-                        verbose = verbose)
+      messagePrepInputs("    cropping...",
+        appendLF = FALSE,
+        verbose = verbose
+      )
       st <- Sys.time()
 
       if (.requireNamespace("sf")) {
@@ -672,8 +713,8 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
           ext <- sf::st_as_sfc(sf::st_bbox(cropToInFromCRS)) # create extent as an object; keeps crs correctly
         } else {
           terraCRSFrom <- terra::crs(from)
-          if (packageVersion("terra") <= "1.5.21") {# an older terra issue; may not be precise version
-            if (length(slotNames(terraCRSFrom)) > 0 ) {
+          if (packageVersion("terra") <= "1.5.21") { # an older terra issue; may not be precise version
+            if (length(slotNames(terraCRSFrom)) > 0) {
               terraCRSFrom <- terraCRSFrom@projargs
             }
           }
@@ -681,8 +722,9 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
           ext <- terra::ext(cropToInFromCRS) # create extent as an object; keeps crs correctly
         }
       }
-      if (isVector(from) && !isSF(from))
+      if (isVector(from) && !isSF(from)) {
         ext <- terra::vect(ext)
+      }
 
       # This is only needed if crop happens before a projection... need to cells beyond edges so projection is accurate
       if (needBuffer) {
@@ -700,10 +742,12 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
           if (isTRUE(suppressWarnings(terra::is.lonlat(ext)))) { # warning is about "crs not defined"
             extTmp2 <- terra::extend(extTmp, 0.1) # hard code 0.1 lat/long, as long as it isn't past the from extent
             extFrom <- terra::ext(from)
-            exts <- c(xmin = max(terra::xmin(extTmp2), terra::xmin(extFrom)),
-                      ymin = max(terra::ymin(extTmp2), terra::ymin(extFrom)),
-                      xmax = min(terra::xmax(extTmp2), terra::xmax(extFrom)),
-                      ymax = min(terra::ymax(extTmp2), terra::ymax(extFrom)))
+            exts <- c(
+              xmin = max(terra::xmin(extTmp2), terra::xmin(extFrom)),
+              ymin = max(terra::ymin(extTmp2), terra::ymin(extFrom)),
+              xmax = min(terra::xmax(extTmp2), terra::xmax(extFrom)),
+              ymax = min(terra::ymax(extTmp2), terra::ymax(extFrom))
+            )
             ext <- if (packageVersion("terra") <= "1.5-21") {
               terra::ext(exts)
             } else {
@@ -712,14 +756,13 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
           } else {
             ext <- terra::extend(extTmp, res[1] * 2)
           }
-
         }
       }
 
       attempt <- 1
       while (attempt <= 2) {
         if (isGridded(from)) {
-          if (!isSpat(from)) {# terra::crop can handle Raster but only if ext is `extent`
+          if (!isSpat(from)) { # terra::crop can handle Raster but only if ext is `extent`
             .requireNamespace("raster", stopOnFALSE = TRUE)
             ext <- raster::extent(ext[])
           }
@@ -730,23 +773,27 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
           } else {
             fromInt <- try(terra::crop(from, ext), silent = TRUE)
           }
-
         }
 
         wasError <- is(fromInt, "try-error")
         noOverlap <- NROW(fromInt) == 0
         if (noOverlap || wasError) {
           fail <- FALSE
-          if (wasError)
-            if (grepl("extents do not overlap", fromInt))
+          if (wasError) {
+            if (grepl("extents do not overlap", fromInt)) {
               fail <- TRUE
+            }
+          }
           if (NROW(fromInt) == 0) { # likely don't overlap
             messagePrepInputs("It looks like the cropping results in no data ",
-                             "(do not overlap or no intersection)", verbose = verbose)
+              "(do not overlap or no intersection)",
+              verbose = verbose
+            )
             fail <- FALSE
           }
-          if (fail)
+          if (fail) {
             stop(fromInt)
+          }
         }
 
 
@@ -758,16 +805,20 @@ cropTo <- function(from, cropTo = NULL, needBuffer = FALSE, overwrite = FALSE,
             stop(fromInt)
           }
         } else {
-          if (attempt > 1)
-            messagePrepInputs("...fixed!", verbose = verbose, verboseLevel = 1,
-                              appendLF = FALSE)
+          if (attempt > 1) {
+            messagePrepInputs("...fixed!",
+              verbose = verbose, verboseLevel = 1,
+              appendLF = FALSE
+            )
+          }
           break
         }
         attempt <- attempt + 1
       }
       from <- fromInt
       messagePrepInputs("...done in ", format(difftime(Sys.time(), st), units = "secs", digits = 3),
-                        verbose = verbose)
+        verbose = verbose
+      )
     }
     from <- revertClass(from, origFromClass = origFromClass)
   }
@@ -783,14 +834,15 @@ writeTo <- function(from, writeTo, overwrite = getOption("reproducible.overwrite
                     isStack = NULL, isBrick = NULL, isRaster = NULL,
                     isSpatRaster = NULL,
                     verbose = getOption("reproducible.verbose"), ...) {
-
   remapOldArgs(...) # converts studyArea, rasterToMatch, filename2, useSAcrs, targetCRS
   if (!missing(writeTo)) {
     if (!is.null(writeTo)) {
-
       dPath <- which(...names() %in% "destinationPath")
-      destinationPath <- if (length(dPath)) destinationPath <- ...elt(dPath) else
+      destinationPath <- if (length(dPath)) {
+        destinationPath <- ...elt(dPath)
+      } else {
         getOption("reproducible.destinationPath", ".")
+      }
       if (all(isAbsolutePath(writeTo))) {
         destinationPath <- dirname(writeTo)
         writeTo <- basename(writeTo)
@@ -808,8 +860,10 @@ writeTo <- function(from, writeTo, overwrite = getOption("reproducible.overwrite
 
       if (!any(is.na(writeTo))) {
         .requireNamespace("terra", stopOnFALSE = TRUE)
-        messagePrepInputs("    writing...", appendLF = FALSE,
-                          verbose = verbose)
+        messagePrepInputs("    writing...",
+          appendLF = FALSE,
+          verbose = verbose
+        )
         st <- Sys.time()
 
         if (is.null(isSpatRaster)) isSpatRaster <- isSpat(from) && isGridded(from)
@@ -828,8 +882,10 @@ writeTo <- function(from, writeTo, overwrite = getOption("reproducible.overwrite
             ## and `terra` can't overwrite it even if `overwrite = TRUE`
             ## this can happen when multiple modules touch the same object
             if (!any(file.exists(writeTo))) {
-              from <- terra::writeRaster(from, filename = writeTo, overwrite = FALSE,
-                                         datatype = datatype)
+              from <- terra::writeRaster(from,
+                filename = writeTo, overwrite = FALSE,
+                datatype = datatype
+              )
               writeDone <- TRUE
             } else {
               stop("File can't be unliked for overwrite")
@@ -845,12 +901,16 @@ writeTo <- function(from, writeTo, overwrite = getOption("reproducible.overwrite
         } else if (isRaster) {
           nlyrsFrom <- nlayers2(from)
           if (nlyrsFrom == 1 || length(writeTo) == 1) {
-            from <- terra::writeRaster(from, filename = writeTo, overwrite = overwrite,
-                                       datatype = datatype)
+            from <- terra::writeRaster(from,
+              filename = writeTo, overwrite = overwrite,
+              datatype = datatype
+            )
           } else {
             outs <- lapply(seq(nlyrsFrom), function(ind) {
-              out <- terra::writeRaster(from[[ind]], filename = writeTo[ind], overwrite = overwrite,
-                                        datatype = datatype)
+              out <- terra::writeRaster(from[[ind]],
+                filename = writeTo[ind], overwrite = overwrite,
+                datatype = datatype
+              )
             })
             from <- raster::stack(outs)
           }
@@ -862,12 +922,14 @@ writeTo <- function(from, writeTo, overwrite = getOption("reproducible.overwrite
             eval(parse(text = fe$saveFun[whType]))(from, writeTo)
           } else {
             messagePrepInputs("... nothing written; object not a known object type to write.",
-                              verbose = verbose)
+              verbose = verbose
+            )
           }
         }
         if (isTRUE(writeDone)) {
           messagePrepInputs("...done in ", format(difftime(Sys.time(), st), units = "secs", digits = 3),
-                            verbose = verbose)
+            verbose = verbose
+          )
         } else {
           messagePrepInputs("", verbose = verbose) # need to "end" the line
         }
@@ -896,7 +958,6 @@ readFrom <- function(file) {
 
 postProcessToAssertions <- function(from, to, cropTo, maskTo, projectTo,
                                     verbose = getOption("reproducible.verbose")) {
-
   # sometimes there are quosures
   for (y in ls()) {
     ll <- get(y, inherits = FALSE)
@@ -906,11 +967,14 @@ postProcessToAssertions <- function(from, to, cropTo, maskTo, projectTo,
     }
   }
 
-  if (isSpat(from) || isSpat(to))
-    if (!requireNamespace("terra", quietly = TRUE))
-    stop("Need terra and sf: install.packages(c('terra', 'sf'))")
-  if (isSF(from) || isSF(to))
+  if (isSpat(from) || isSpat(to)) {
+    if (!requireNamespace("terra", quietly = TRUE)) {
+      stop("Need terra and sf: install.packages(c('terra', 'sf'))")
+    }
+  }
+  if (isSF(from) || isSF(to)) {
     if (!requireNamespace("sf", quietly = TRUE)) stop("Need sf: install.packages('sf')")
+  }
 
   if (!(isSpatialAny(from))) stop("from must be a Spat* or sf*")
 
@@ -927,36 +991,43 @@ postProcessToAssertions <- function(from, to, cropTo, maskTo, projectTo,
   }
 
   if (!missing(cropTo)) {
-    if (!is.naSpatial(cropTo))
+    if (!is.naSpatial(cropTo)) {
       if (!is.null(cropTo)) {
-        if (!isSpatialAny(cropTo) && !isCRSANY(cropTo))
+        if (!isSpatialAny(cropTo) && !isCRSANY(cropTo)) {
           stop("cropTo must be a ", .msg$anySpatialClass)
+        }
         # apparently, cropTo can be a gridded object no matter what
         # if (isVector(from)) if (!isVector(cropTo) && !isCRSANY(cropTo))
         #   stop("if from is a Vector object, cropTo must also be a Vector object")
       }
+    }
   }
   if (!missing(maskTo)) {
-    if (!is.naSpatial(maskTo))
+    if (!is.naSpatial(maskTo)) {
       if (!is.null(maskTo)) {
-        if (!isSpatialAny(maskTo) && !isCRSANY(maskTo))
+        if (!isSpatialAny(maskTo) && !isCRSANY(maskTo)) {
           stop("maskTo must be a ", .msg$anySpatialClass)
+        }
         # if (isVector(from)) if (!isVector(maskTo) && !isCRSANY(maskTo))
         #   stop("if from is a Vector object, maskTo must also be a Vector object")
       }
+    }
   }
   if (!missing(projectTo)) {
-    if (!is.naSpatial(projectTo))
+    if (!is.naSpatial(projectTo)) {
       if (!is.null(projectTo)) {
-        if (isCRScharacter(projectTo))
+        if (isCRScharacter(projectTo)) {
           projectTo <- try(silent = TRUE, sf::st_crs(projectTo))
+        }
         if (!isCRSANY(projectTo)) {
-          if (!isSpatialAny(projectTo))
+          if (!isSpatialAny(projectTo)) {
             stop("projectTo must be a ", .msg$anySpatialClass)
+          }
           # if (isVector(from)) if (!isVector(projectTo))
           # stop("if from is a Vector object, projectTo must also be a Vector object")
         }
       }
+    }
   }
 
   return(invisible())
@@ -964,10 +1035,11 @@ postProcessToAssertions <- function(from, to, cropTo, maskTo, projectTo,
 
 is.naSpatial <- function(x) {
   isna <- FALSE
-  if (!is.null(x))
+  if (!is.null(x)) {
     if (!isSpatialAny(x)) {
       if (all(is.na(x))) isna <- TRUE
     }
+  }
   isna
 }
 
@@ -976,13 +1048,17 @@ cropSF <- function(from, cropToVect, verbose = getOption("reproducible.verbose")
   if (isSF(from) && (isSF(cropToVect) || is(cropToVect, "Spatial"))) {
     .requireNamespace("sf", stopOnFALSE = TRUE)
     messagePrepInputs("    pre-cropping because `from` is sf and cropTo is sf/Spatial*",
-                      verbose = verbose)
+      verbose = verbose
+    )
     attempt <- 1
     while (attempt <= 2) {
-
-      from2 <- try(sf::st_crop(from, sf::st_transform(sf::st_as_sfc(sf::st_bbox(cropToVect)),
-                                                        sf::st_crs(from))),
-                     silent = TRUE)
+      from2 <- try(
+        sf::st_crop(from, sf::st_transform(
+          sf::st_as_sfc(sf::st_bbox(cropToVect)),
+          sf::st_crs(from)
+        )),
+        silent = TRUE
+      )
       if (is(from2, "try-error")) {
         if (attempt == 1) {
           messageDeclareError(error = from2, fromFnName = "cropSF", verbose)
@@ -991,26 +1067,31 @@ cropSF <- function(from, cropToVect, verbose = getOption("reproducible.verbose")
           stop(from2)
         }
       } else {
-        if (attempt > 1)
-          messagePrepInputs("...fixed!", verbose = verbose, verboseLevel = 1,
-                            appendLF = FALSE)
+        if (attempt > 1) {
+          messagePrepInputs("...fixed!",
+            verbose = verbose, verboseLevel = 1,
+            appendLF = FALSE
+          )
+        }
         break
       }
 
       attempt <- attempt + 1
-
-
     }
-    if (extntNA(from2))
+    if (extntNA(from2)) {
       messagePrepInputs("    resulting extent is NA, probably because objects don't overlap",
-                        verbose = verbose)
-    if (!is(from2, "try-error"))
+        verbose = verbose
+      )
+    }
+    if (!is(from2, "try-error")) {
       from <- from2
+    }
 
     messagePrepInputs("  done in ", format(difftime(Sys.time(), st),
-                                           units = "secs", digits = 3),
-                      verbose = verbose)
-
+      units = "secs", digits = 3
+    ),
+    verbose = verbose
+    )
   }
   from
 }
@@ -1027,7 +1108,6 @@ revertClass <- function(from, isStack = FALSE, isBrick = FALSE, isRasterLayer =
       isRasterLayer <- any(origFromClass == "RasterLayer")
       isSF <- any(origFromClass == "sf")
       isSpatial <- any(startsWith(origFromClass, "Spatial"))
-
     }
     if (isStack && !is(from, "RasterStack")) from <- raster::stack(from) # coming out of writeRaster, becomes brick
     if (isBrick && !is(from, "RasterBrick")) from <- raster::brick(from) # coming out of writeRaster, becomes brick
@@ -1046,13 +1126,13 @@ revertClass <- function(from, isStack = FALSE, isBrick = FALSE, isRasterLayer =
 messageDeclareError <- function(error, fromFnName, verbose = getOption("reproducible.verbose")) {
   errWOWordError <- gsub("Error {0,1}: ", "", error)
   messagePrepInputs("    ", fromFnName, " resulted in following error: \n    - ", errWOWordError, "    --> attempting to fix",
-                    appendLF = FALSE, verbose = verbose, verboseLevel = 1)
+    appendLF = FALSE, verbose = verbose, verboseLevel = 1
+  )
 }
 
 #' @importFrom stats na.omit
 remapOldArgs <- function(..., fn = sys.function(sys.parent()), envir = parent.frame(),
                          verbose = getOption("reproducible.verbose")) {
-
   forms <- formals(fn)
   dots <- list(...)
   dots <- dots[!vapply(dots, is.null, FUN.VALUE = logical(1))]
@@ -1066,11 +1146,12 @@ remapOldArgs <- function(..., fn = sys.function(sys.parent()), envir = parent.fr
   # Second, what is supplied
   remap <- .remappings[oldUsed]
 
-  newHereAll <- intersect(unname(unlist(remap)),
-                          names(forms))
+  newHereAll <- intersect(
+    unname(unlist(remap)),
+    names(forms)
+  )
 
   if (length(newHereAll)) {
-
     # remove iterative duplication e.g., cropTo should only come from rtm if both rtm and sa supplied
     newHere <- character()
     Map(re = rev(remap), nam = names(rev(remap)), function(re, nam) {
@@ -1079,15 +1160,18 @@ remapOldArgs <- function(..., fn = sys.function(sys.parent()), envir = parent.fr
       remap[[nam]] <<- newOnes
     })
 
-    Map(elem = oldUsed, newHere = remap,
-        function(elem, newHere) {
-          if (length(elem)) {
-            mes <- paste(newHere, collapse = ", ")
-            messagePrepInputs(elem, " is supplied (deprecated); assigning it to ", mes,
-                              verbose = verbose)
-            lapply(newHere, function(nh) ret[nh] <<- list(dots[[elem]]))
-          }
-        })
+    Map(
+      elem = oldUsed, newHere = remap,
+      function(elem, newHere) {
+        if (length(elem)) {
+          mes <- paste(newHere, collapse = ", ")
+          messagePrepInputs(elem, " is supplied (deprecated); assigning it to ", mes,
+            verbose = verbose
+          )
+          lapply(newHere, function(nh) ret[nh] <<- list(dots[[elem]]))
+        }
+      }
+    )
     if (isTRUE(dots$useSAcrs)) {
       ret$projectTo <- dots$studyArea
     }
@@ -1107,11 +1191,13 @@ remapOldArgs <- function(..., fn = sys.function(sys.parent()), envir = parent.fr
 }
 
 
-.remappings <- list(studyArea = c("cropTo", "maskTo"),
-                    rasterToMatch = c("cropTo", "projectTo", "to"),
-                    filename2 = "writeTo",
-                    targetCRS = "projectTo",
-                    useSAcrs = "projectTo")
+.remappings <- list(
+  studyArea = c("cropTo", "maskTo"),
+  rasterToMatch = c("cropTo", "projectTo", "to"),
+  filename2 = "writeTo",
+  targetCRS = "projectTo",
+  useSAcrs = "projectTo"
+)
 
 
 assessDataTypeOuter <- function(from, method) {
@@ -1123,7 +1209,9 @@ assessDataTypeOuter <- function(from, method) {
 
     isInt <- if (inherits(from, "Raster")) {
       if (nlayers2(from) == 1) is.integer(from[]) else apply(from[], 2, is.integer)
-    } else { terra::is.int(from) }
+    } else {
+      terra::is.int(from)
+    }
 
     if (isTRUE(any(whMethodBilin & isInt))) {
       warning("method is bilinear, but the data are integer; please confirm this is correct")
@@ -1137,9 +1225,10 @@ assessDataTypeOuter <- function(from, method) {
 }
 
 
-writeRasterArgs <- c("filename", "overwrite", "ncopies", "steps", "filetype", "progressbar", "tempdir",
-                     "todisk", "memfrac", "progress", "verbose", "memmin", "filetype",
-                     "verbose", "names", "tolerance", "overwrite", "datatype", "memmax"
+writeRasterArgs <- c(
+  "filename", "overwrite", "ncopies", "steps", "filetype", "progressbar", "tempdir",
+  "todisk", "memfrac", "progress", "verbose", "memmin", "filetype",
+  "verbose", "names", "tolerance", "overwrite", "datatype", "memmax"
 )
 
 projectArgs <- c("x", "y", "method", "mask", "align", "gdal", "res", "origin", "threads", "filename")
@@ -1147,9 +1236,9 @@ projectArgs <- c("x", "y", "method", "mask", "align", "gdal", "res", "origin", "
 maskArgs <- c("x", "inverse", "mask", "updatevalue", "touches", "filename")
 
 extntNA <- function(x) {
-  out <- if (isSF(x))
+  out <- if (isSF(x)) {
     sf::st_bbox(x)
-  else {
+  } else {
     if (isSpat(x) || isRaster(x)) {
       terra::ext(x)
     } else {
